@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from django.conf import settings
 from django.forms.formsets import BaseFormSet
 from django.template import Context
 from django.template.loader import get_template
@@ -10,6 +11,8 @@ register = template.Library()
 # We import the filters, so they are available when doing load crispy_forms_tags
 from crispy_forms_filters import *
 
+TEMPLATE_PACK = getattr(settings, 'CRISPY_TEMPLATE_PACK', 'bootstrap')
+
 
 class ForLoopSimulator(object):
     """
@@ -91,6 +94,7 @@ class BasicNode(template.Node):
         # We get the response dictionary 
         is_formset = isinstance(actual_form, BaseFormSet)
         response_dict = self.get_response_dict(attrs, context, is_formset)
+        context.update(response_dict)
 
         # If we have a helper's layout we use it, for the form or the formset's forms
         if helper and helper.layout:
@@ -133,18 +137,24 @@ class BasicNode(template.Node):
             'form_error_title': attrs.get("form_error_title", None),
             'formset_error_title': attrs.get("formset_error_title", None),
             'form_show_errors': attrs.get("form_show_errors", True),
+            'help_text_inline': attrs.get("help_text_inline", False),
             'inputs': attrs.get('inputs', []),
             'is_formset': is_formset,
         }
 
+        # Handles custom attributes added to helpers
+        for attribute_name, value in attrs.items():
+            if attribute_name not in response_dict:
+                response_dict[attribute_name] = value
+
         if context.has_key('csrf_token'):
             response_dict['csrf_token'] = context['csrf_token']
 
         return response_dict
 
 
-whole_uni_formset_template = get_template('uni_form/whole_uni_formset.html')
-whole_uni_form_template = get_template('uni_form/whole_uni_form.html')
+whole_uni_formset_template = get_template('%s/whole_uni_formset.html' % TEMPLATE_PACK)
+whole_uni_form_template = get_template('%s/whole_uni_form.html' % TEMPLATE_PACK)
 
 class UniFormNode(BasicNode):
     def render(self, context):
@@ -152,12 +162,12 @@ class UniFormNode(BasicNode):
 
         if c['is_formset']:
             if settings.DEBUG:
-                template = get_template('uni_form/whole_uni_formset.html')
+                template = get_template('%s/whole_uni_formset.html' % TEMPLATE_PACK)
             else:
                 template = whole_uni_formset_template
         else:
             if settings.DEBUG:
-                template = get_template('uni_form/whole_uni_form.html')
+                template = get_template('%s/whole_uni_form.html' % TEMPLATE_PACK)
             else:
                 template = whole_uni_form_template
 
