@@ -49,7 +49,7 @@ class TestBasicFunctionalityTags(TestCase):
 
         c = Context({'form': form})
         html = template.render(c)
-        self.assertFalse("errorMsg" in html or "alert-message" in html)
+        self.assertFalse("errorMsg" in html or "alert" in html)
 
     def test_as_crispy_errors_form_with_non_field_errors(self):
         template = get_template_from_string(u"""
@@ -61,7 +61,7 @@ class TestBasicFunctionalityTags(TestCase):
 
         c = Context({'form': form})
         html = template.render(c)
-        self.assertTrue("errorMsg" in html or "alert-message" in html)
+        self.assertTrue("errorMsg" in html or "alert" in html)
         self.assertTrue("<li>Passwords dont match</li>" in html)
         self.assertFalse("<h3>" in html)
 
@@ -167,7 +167,7 @@ class TestFormHelpers(TestCase):
         self.assertTrue('id="this-form-rocks">' in html)
         self.assertTrue('action="%s"' % reverse('simpleAction') in html)
 
-        self.assertTrue("<h3>ERRORS</h3>" in html)
+        self.assertTrue("ERRORS" in html)
         self.assertTrue("<li>Passwords dont match</li>" in html)
 
         # now lets remove the form tag and render it again. All the True items above
@@ -419,7 +419,7 @@ class TestFormLayout(TestCase):
                     css_class = "columns",
                 ),
                 ButtonHolder(
-                    Submit('Save', 'Save', css_class='button white'),
+                    Submit('Save the world', 'Save', css_class='button white'),
                 ),
                 Div(
                     'password1', 
@@ -444,7 +444,7 @@ class TestFormLayout(TestCase):
         self.assertTrue('class="formColumn columns"' in html)
         self.assertTrue('class="buttonHolder">' in html)
         self.assertTrue('input type="submit"' in html)
-        self.assertTrue('name="save"' in html)
+        self.assertTrue('name="save-the-world"' in html)
         self.assertTrue('id="custom-div"' in html)
         self.assertTrue('class="customdivs"' in html)
 
@@ -491,7 +491,7 @@ class TestFormLayout(TestCase):
         self.assertTrue('class="formColumn columns"' in html)
         self.assertTrue('class="buttonHolder">' in html)
         self.assertTrue('input type="submit"' in html)
-        self.assertTrue('name="save"' in html)
+        self.assertTrue('name="Save"' in html)
         self.assertTrue('id="custom-div"' in html)
         self.assertTrue('class="customdivs"' in html)
         self.assertFalse('last_name' in html)
